@@ -63,6 +63,8 @@ class HubIO:
     """
 
     def __init__(self, args: argparse.Namespace):
+        # !!! `args` here are not only parsed by `jina-hub` but also `jina` itself (e.g. `jina pod`)
+        # So you need to check self.args with `hasattr`
         self.args = args
         self.logger = logging.getLogger(self.__class__.__name__)
 
@@ -471,6 +473,10 @@ metas:
                 build_env_dict[env_list[0]] = env_list[1]
             build_env = build_env_dict if build_env_dict else None
 
+        platform = None
+        if hasattr(self.args, 'platform'):
+            platform = self.args.platform
+
         requirements_file = work_path / 'requirements.txt'
 
         requirements_env_variables = []
@@ -553,6 +559,9 @@ metas:
                 if build_env:
                     form_data['buildEnv'] = json.dumps(build_env)
 
+                if platform:
+                    form_data['platform'] = platform
+
                 st.update('Connecting to Jina Hub ...')
 
                 if self.args.force_update and self.args.secret:
@@ -987,6 +996,8 @@ metas:
         console = get_rich_console()
         self._prettyprint_list_usage(console, executors, base_path)
 
+    # !!! Warning: changing parameters here causes tests in jina to fail.
+    # You need to change the tests in jina as well.
     @staticmethod
     @disk_cache_offline(cache_file=str(get_cache_db()))
     def fetch_meta(
@@ -995,6 +1006,7 @@ metas:
         image_required: bool = True,
         rebuild_image: bool = True,
         *,
+        prefer_platform: Optional[str] = None,
         secret: Optional[str] = None,
         force: bool = False,
     ) -> HubExecutor:
@@ -1014,12 +1026,31 @@ metas:
         """
         import requests
 
+        req_header = get_request_header()
+
         @retry(num_retry=3)
         def _send_request_with_retry(url, **kwargs):
             resp = requests.post(url, **kwargs)
             if resp.status_code != 200:
-                if resp.text:
+                if resp.json():
+                    hubble_err = resp.json()
+                    overridden_msg = ''
+                    detail_msg = ''
+                    msg = ''
+                    if isinstance(hubble_err, dict):
+                        (overridden_msg, detail_msg) = get_hubble_error_message(
+                            hubble_err
+                        )
+                        if not msg:
+                            msg = detail_msg
+
+                    raise Exception(
+                        f'{overridden_msg or msg or "Unknown Error"} '
+                        f'session_id: {req_header.get("jinameta-session-id")}'
+                    )
+                elif resp.text:
                     raise Exception(resp.text)
+
                 resp.raise_for_status()
 
             return resp
@@ -1033,8 +1064,8 @@ metas:
             payload['secret'] = secret
         if tag:
             payload['tag'] = tag
-
-        req_header = get_request_header()
+        if prefer_platform:
+            payload['preferPlatform'] = prefer_platform
 
         resp = _send_request_with_retry(pull_url, json=payload, headers=req_header)
         resp = get_json_from_response(resp)['data']
@@ -1204,6 +1235,10 @@ metas:
         executor_name = None
         build_env = None
         scheme = None
+        prefer_platform = None
+
+        if hasattr(self.args, 'prefer_platform'):
+            prefer_platform = self.args.prefer_platform
 
         try:
             need_pull = self.args.force_update
@@ -1216,6 +1251,8 @@ metas:
                     name,
                     tag,
                     image_required,
+                    True,
+                    prefer_platform=prefer_platform,
                     secret=secret,
                     force=need_pull,
                 )
